@@ -1,9 +1,12 @@
 from utf_queue_client.scripts.ubai_search_cli import cli
+from utf_queue_client.clients import create_span_decorator
 import os
 import subprocess
 import sys
 
+span_decorator = create_span_decorator()
 
+@span_decorator
 def test_ubai_search_cli():
     metadata = [
         ("app_name", "ubai_unit_test"),
@@ -17,6 +20,7 @@ def test_ubai_search_cli():
     assert len(results) == 1
 
 
+@span_decorator
 def test_ubai_search_cli_script():
     metadata = [
         ("app_name", "ubai_unit_test"),
