@@ -1,10 +1,13 @@
 import pytest
 
 from utf_queue_client.scripts.ubai_upload_cli import cli
+from utf_queue_client.clients import create_span_decorator
 import os
 import subprocess
 import sys
 
+span_decorator = create_span_decorator()
+
 
 @pytest.fixture
 def metadata():
@@ -17,6 +20,7 @@ def metadata():
     ]
 
 
+@span_decorator
 def test_ubai_upload_cli(request, metadata):
     file = os.path.join(os.path.dirname(__file__), "test.hex")
 
@@ -26,6 +30,7 @@ def test_ubai_upload_cli(request, metadata):
     cli(file, metadata, username, password, client_id)
 
 
+@span_decorator
 def test_ubai_upload_cli_script(request, metadata):
     file = os.path.join(os.path.dirname(__file__), "test.hex")
 
