@@ -5,7 +5,7 @@ from ..models import SqaAppBuildResult
 from ..models import SqaTestResult
 from ..models import SqaTestSession
 from ..models import QueueMessage
-from . import Loggable
+from . import Loggable, create_span_decorator
 from socket import gethostname
 from datetime import datetime
 from abc import ABC, abstractmethod
@@ -17,6 +17,8 @@ __all__ = [
     "SqaTestResultProducerFactory",
 ]
 
+span_decorator = create_span_decorator()
+
 
 class BaseSqaTestResultProducer(ABC):
     @abstractmethod
@@ -56,6 +58,7 @@ class SqaTestResultProducer(BaseSqaTestResultProducer):
             persistent=True,
         )
 
+    @span_decorator
     def publish_test_result(self, test_result: SqaTestResult):
         queue_message = QueueMessage(
             payload=test_result,
@@ -66,6 +69,7 @@ class SqaTestResultProducer(BaseSqaTestResultProducer):
         )
         self._publish_message(queue_message)
 
+    @span_decorator
     def publish_test_session(self, subtype: str, test_session: SqaTestSession):
         queue_message = QueueMessage(
             payload=test_session,
@@ -76,12 +80,15 @@ class SqaTestResultProducer(BaseSqaTestResultProducer):
         )
         self._publish_message(queue_message)
 
+    @span_decorator
     def publish_test_session_start(self, test_session: SqaTestSession):
         self.publish_test_session("SESSION_START", test_session)
 
+    @span_decorator
     def publish_test_session_stop(self, test_session: SqaTestSession):
         self.publish_test_session("SESSION_STOP", test_session)
 
+    @span_decorator
     def publish_app_build_result(
         self,
         app_build_result: SqaAppBuildResult,
@@ -100,7 +107,9 @@ class LocalSqaTestResultProducer(SqaTestResultProducer):
     def __init__(self):
         super().__init__(
             "amqp://guest:guest@localhost:5672/%2f",
-            f"LocalSqaTestResultProducer at {gethostname()}",
+            os.environ.get(
+                "UTF_PRODUCER_APP_ID", f"LocalSqaTestResultProducer at {gethostname()}"
+            ),
         )
 
 
@@ -129,8 +138,12 @@ class SqaTestResultProducerFactory(Loggable):
     @classmethod
     def create_producer(cls, raise_on_connection_error=False):
         try:
-            if os.environ.get("UTF_QUEUE_SERVER_URL") is not None:
-                return SqaTestResultProducer()
+            queue_server_url = os.environ.get("UTF_QUEUE_SERVER_URL")
+            if queue_server_url is not None:
+                return SqaTestResultProducer(
+                    url=queue_server_url,
+                    producer_app_id=os.environ.get("UTF_PRODUCER_APP_ID"),
+                )
             else:
                 return LocalSqaTestResultProducer()
         except ConnectionError as e:
